=======
Credits
=======

List of contributors is available at
`GitHub <https://github.com/sunscrapers/djoser/graphs/contributors>`_
or just ``git shortlog -s``

Thank you all for making djoser happen.
